aboutsummaryrefslogtreecommitdiff
path: root/main.js
diff options
context:
space:
mode:
authorChristoph Settgast <csett86@web.de>2022-08-12 07:46:41 +0200
committerGitHub <noreply@github.com>2022-08-12 07:46:41 +0200
commit27f663a98f1331d5b9622c566c9516f8cd0983c9 (patch)
treea985ced7887e38a0dedcb6b3649bdc44b8d88297 /main.js
parenteb95561b576d3420f98710e3fd315bb9858a24d0 (diff)
feat(wayland): enable titlebar when running under wayland (#766)
Use with --ozone-platform-hint=auto to enable Closes: #683
Diffstat (limited to 'main.js')
-rw-r--r--main.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/main.js b/main.js
index c738a93..ee35221 100644
--- a/main.js
+++ b/main.js
@@ -40,9 +40,9 @@ app.commandLine.appendSwitch('disable-features', 'IOSurfaceCapturer');
// Enable Opus RED field trial.
app.commandLine.appendSwitch('force-fieldtrials', 'WebRTC-Audio-Red-For-Opus/Enabled/');
// Enable optional PipeWire support.
if (!app.commandLine.hasSwitch('enable-features')) {
- app.commandLine.appendSwitch('enable-features', 'WebRTCPipeWireCapturer');
+ app.commandLine.appendSwitch('enable-features', 'WebRTCPipeWireCapturer,WaylandWindowDecorations');
}
autoUpdater.logger = require('electron-log');
@@ -40,9 +40,9 @@ app.commandLine.appendSwitch('disable-features', 'IOSurfaceCapturer');
// Enable Opus RED field trial.
app.commandLine.appendSwitch('force-fieldtrials', 'WebRTC-Audio-Red-For-Opus/Enabled/');
-// Enable optional PipeWire support.
+// Wayland: Enable optional PipeWire and window decorations support.
if (!app.commandLine.hasSwitch('enable-features')) {